*=====================================================================================*
*                                  prep.do                                     *
*=====================================================================================*

*-------------------------------------------------------------------------------------*
*  van den Berg, Verbakel, 2023, replication files                            *
*  last update: *
*-------------------------------------------------------------------------------------*

clear
set more off

*-----------------------------------------------------------------------------*
*  Prepare different data sets                                                          *
*-----------------------------------------------------------------------------*
*-----------------------------------------------------------------------------*

*-----------------------------------------------------------------------------*
* Parents' identifier
/* We make the identifier of the parents via these datasets:
- First year young adult is observed after age 16. 
- Kidl */

** Make identifier by using the relation to head of household. 
use "${data}\pbrutto.dta", clear
merge 1:1 pid syear using  "${data}\pgen.dta", nogen keepusing (pid syear pgpartnr)

recode pid pgpartnr (-2000/0 = . )
tostring pid pgpartnr, gen(pidb pgpartnerb)
gen head			=	pidb 		if 	stell_h==0  					
gen headp			=	pidb 		if 	stell_h==11 | stell_h==12 | stell_h==13		
gen headp2			=	pgpartner	if 	stell_h==0

foreach var of varlist head headp headp2 {
	sort hid syear
	bys hid syear: egen `var'a		=	mode(`var')
	}
	*
// code bio as the head of the household if the person is child of hhd
// code bio as partner head of the household if the person is stepchild hhd 
gen bio1		=	heada 		if			stell_h==20 				| 	///
											stell_h==21				| 	///
											stell_h==23				| 	///
											stell_h==24
replace bio1	=	headpa		if			stell_h==22 & bio1==""	
replace bio1	=	headp2a		if			stell_h==22 & bio1==""		

drop if geburt_v2<1
gen age	=	syear	-	geburt_v2
keep if age>15			// keep only observations after age 15 to identify parents in adolescence 
sort pid syear
bys pid: gen n = _n
keep if n==1

keep pid syear bio1  

save "${posted}\parentid.dta", replace

** Make identifier by using kidl
use "${data}\kidlong.dta", clear 
merge 1:1 pid syear using  "${data}\pequiv.dta", keep( 1 3) ///
		keepusing(pid syear d11101)

gen birthyear = syear-d11101
sort pid syear   
bysort pid : egen bio2 = mode(k_relf)				// head of household
bysort pid : egen bio3 = mode(k_pmum)				// mother
bysort pid: gen n=_n
keep if n==1
keep pid bio2 bio3 birthyear hid
save "${posted}\kidb.dta", replace

*-----------------------------------------------------------------------------*
* Prepare datafiles parents
// save data as partner's data (later to be merged with partner id parent) 
use "${data}\pl.dta", clear

keep pid hid syear 
tostring pid, replace

rename * x*

save "${posted}\parentsb.dta", replace

*-----------------------------------------------------------------------------*
*  Merge datasets                                                          	  *
*-----------------------------------------------------------------------------*
use "${data}\pequiv.dta", clear
keep pid hid syear d11102ll d11101 d11107  d11109 h11101 h11102 i11110
merge 1:1 pid syear using "${data}\pbrutto.dta", 								///
	keep(1 3) keepusing(pid syear stell_h) nogen
merge 1:1 pid syear using "${data}\jugendl.dta", 								/// 
	keep(1 3) keepusing(pid syear  jl0392  ) 									// not everyone is in youth questionnaire
rename _merge mergedjugendl
merge 1:1 pid syear using "${data}\pl.dta", 									/// 
	keep(1 3) keepusing(pid hid syear pld0133 									///
						plh0180 plh0182 plh0175 plg0012-plg0068) 
rename _merge mergedpl	
merge 1:1 pid syear using "${data}\pgen.dta", 									/// 
	keep(1 3) keepusing(pid syear pgfamstd pgpartz pgpartnr pgemplst) nogen
merge m:1 pid using "${posted}\kidb.dta", 										///
	keep(1 3) nogen 
merge m:1 pid using "${posted}\parentid.dta", 									///
	keep(1 3) nogen 

drop if mergedjugendl==1 & mergedpl==1	// Only keep young adults who participated in youth or main questionnaire

** Make all of the variables of the 1-wave jugendl on individual cluster level 
foreach var of varlist jl*{
	bys pid: egen `var'max = max(`var')
	replace `var' = `var'max
	drop `var'max
	}
	*

*-----------------------------------------------------------------------------*
*-----------------------------------------------------------------------------*
*  Make variables		                                                      *
*-----------------------------------------------------------------------------*
*** Age
// make min and max age to know what age period the individuals are observed
// keep only from young adulthood onward
gen age = d11101
keep if age>=15																
sort pid syear
bys pid: egen min_age = min(age)
bys pid: egen max_age = max(age)
recode age (18/23 = 1) (24/29 = 2) (30/34 =3 ) (35/39=4) (40/44=5), gen(agegrp)

*** Leaving home
/* identify whether people live in parental home to determine whether they move 
in with a partner after leaving home*/
// keep only youth living with parents at start
sort pid syear
gen livepar 	= 1 if 	stell_h>19 & stell_h<25 
gen livpary1a 	= 1 if 	min_age==age & livepar==1 
bys pid: egen livpary1 = max(livpary1a)
drop livpary1a
drop if livpary1==.		

// merge with two parents if there are two identifiers 
gen biopar  = "." 
gen biopar2	= "." 
tostring bio2 bio3, replace 
foreach var of varlist bio1 bio2 bio3 {
	replace `var'	=	"."		if `var'=="" 	| `var'=="-2" | `var'=="-8"
	replace biopar	=	`var'	if biopar=="." 	
	replace biopar2	=	`var'	if biopar2=="." & biopar!=`var'
	}
	*
rename (syear biopar) (xsyear xpid)
merge m:1 xpid xsyear using "${posted}\parentsb.dta", keep(1 3)
rename _merge biomerge
rename x* biox*

rename (bioxsyear biopar2) (xsyear xpid)
merge m:1 xpid xsyear using "${posted}\parentsb.dta", keep(1 3)
rename _merge biomerge2
rename xsyear syear
rename x* bio2x*

// determine leaving home using relation to head of the household and presence of parents in household
gen leaveh = 1 if 	livepar==. & 	hid!=bioxhid & hid!=bio2xhid & stell<20 | ///
									hid!=bioxhid & hid!=bio2xhid & stell>28
recode leaveh (. = 0 )
bys pid: egen evmoved = max(leaveh)

/// yearleft home
gen yleaveha = syear if leaveh==1
bys pid: egen yleaveh = min(yleaveha)

*** Gender, man 
recode d11102ll (1=1) (2=0), gen(man)


*** Life satisfaction, lsat
// replace missings with previous or next year
recode plh0182 (-5 -2 -1 = .), gen(lsat)
replace lsat = jl0392 if lsat==. & jl0392>=0 & jl0392!=. & age==min_age		// youth questionnaire data 
sort pid syear
bys pid: replace lsat = lsat[_n-1] if lsat==.
bys pid: replace lsat = lsat[_n+1] if lsat==.		

* Number of other household members that are children of head household, hhdmem
gen hhdmem = h11101 + h11102
replace hhdmem = hhdmem - 1 if age<18

* Partner/relationship variables				
recode pgfamstd		(1 6 7 		=	1	"Partner") 		///
					(else		=	0	"Single")		///
					, gen(partner)				
replace partner = 1 	if 	pld0133==1 | pld0133==-8 & pgpartz==2
replace partner = 0		if pld0133==2

sort pid syear
bys pid: gen unpartnered=1 if partner==0 & partner[_n-1]==1
gen yunpartnered = syear if unpartnered==1
bys pid: egen min_yunpartnered = min(yunpartnered)
gen ysinceunpartnered = syear-min_yunpartnered

// age partnering
gen agepartn = age if partner==1 & syear>=yleaveh
bys pid: egen agepart = min(agepartn)

// unpartnering
gen unpart=1 if age>agepart & partner==0
recode unpart (. = 0)
bys pid: egen max_unpart = max(unpart)

// single
gen agemova = age if syear==yleaveh
bys pid: egen agemov = min(agemova)
gen  yearssing = agepart-agemov
recode yearssing (-9/0 = 0) (8/19=8), gen(yearssingb)		// topcoded
recode yearssing (0 = 0) (else = 1), gen(sing)

// age unpartnering
gen ageunparta= age if unpart==1
bys pid: egen ageunpart = min(ageunparta)

// year unpartnering
gen yunparta= syear if unpart==1
bys pid: egen yunpart = min(yunparta)

* Control variable: having a child
recode d11107 (0 = 0) (else = 1), gen(child) 


* Make variable for whether the couple is opposite or same sex couple
gen manheada = 1 if stell_h==0 & d11102ll==1
replace manheada=0 if stell_h==0 & d11102ll==2

// code head of the household
recode stell_h (11 12 13 = 1), gen(partnerhead)

gen manparta = 1 if partnerhead==1 & d11102ll==1
replace manparta=0 if partnerhead==1 & d11102ll==2

bys hid syear: egen manhead = max(manheada)
bys hid syear: egen manpart = max(manparta)

// couple is 1 if opposite sex couple, couple is 2 if same sex couple
gen couple = 1 if manhead==1 & manpart==0 | manhead==0 & manpart==1
replace couple = 2 if manhead==1 & manpart==1 | manhead==0 & manpart==0

// years from to unpartnering
gen yunpar = syear-yunpart

** gen education year before divorce
gen eduybfa = d11109 if yunpar==-1
bys pid: egen edybf = max(eduybfa)
bys pid: egen edumax = max(d11109)
replace edybf = edumax if edybf<0

/*-----------------------------------------------------------------------------
	Sample selection 
-----------------------------------------------------------------------------*/
* Drop people who are only observed once or started after age 23
keep if min_age<25

* Drop people who are observed leaving home
drop if evmoved==0

* keep people from moment of leaving home onwards
distinct pid
drop if age<agemov	
distinct pid

save "${posted}\data2.dta", replace


use "${posted}\data2.dta", clear

* Keep only people who experience separation 
keep if max_unpart ==1 
distinct pid
gen yearspartnered = ageunpart - agepart
keep if age>=agepart						// keep only from partnering onwards

// make variable for years since/from unpartnered
recode yunpar 	(-3 = 1 "-3") (-2 = 2 "-2") (-1 = 3  "-1") ///
				(0 = 4 "0") (1 = 5 "1") (2 = 6 "2") (3 = 7 "3")  (else=.) , gen(yupar)
drop if yupar==.		// keep only from -3 to +3 window
sort pid syear
bys pid: egen min_yunpar = min(yupar)
bys pid: egen max_yunpar = max(yupar)


// keep only if not repartnered
drop if yupar>4 & partner==1

// keep to age 45
keep if age<45
distinct pid

// keep only if observed before and after
keep if min_yunpar<4 & max_yunpar>=4
distinct pid


// set data
xtset pid yupar 
distinct pid
label language EN

save "${posted}\data3.dta", replace
