*** Descriptives
* TABLE 1
use "${posted}\data3.dta", clear

drop if  lsat<0 | d11109<0
distinct pid if sing==1 & man==1
distinct pid  if sing==0 & man==1
distinct pid  if sing==1 & man==0
distinct pid  if sing==0 & man==0


// Table O1
fre yupar if sing==1 & man==1
fre yupar if sing==0 & man==1
fre yupar if sing==1 & man==0
fre yupar if sing==0 & man==0


keep if yupar==3


foreach var of varlist i11110 child yearssingb lsat yearspartnered d11109 age {
	sum `var'
}
*

fre agegrp

foreach var of varlist i11110 child yearssingb lsat yearspartnered d11109 age {
	sum `var' if sing==1 & man==1
	sum `var' if sing==0 & man==1
	sum `var' if sing==1 & man==0
	sum `var' if sing==0 & man==0
	ttest `var' if man==0, by(sing)
	ttest `var' if man==1, by(sing)
}
*
foreach var of varlist agegrp {
	fre `var' if sing==1 & man==1
	fre `var' if sing==0 & man==1
	fre `var' if sing==1 & man==0
	fre `var' if sing==0 & man==0
}
*
tab agegrp sing if man==0, chi
tab agegrp sing if man==1, chi

** Robustness check: do the groups differ in these aspects
// Calendar year, percentage being married, years partnered, and age at leaving home 
recode pgfamstd (1 2 5 6 = 1) (else=0), gen(married)
foreach var of varlist syear married  yearspartnered agemov {
	fre `var'
	ttest `var' if man==0, by(sing)
	ttest `var' if man==1, by(sing)
}
*

********************************************************************************
* Life Satisfaction
********************************************************************************

set scheme plotplain 
use "${posted}\data3.dta", clear

// main analyses without missing, robstness check with 
drop if  lsat<0 | edumax<0					
drop if yupar<2
center edumax

*** Fixed effects models life satisfaction
** Figure 1 

// women
preserve
keep if  sing==1 & man==0 
xtreg  lsat ib3.yupar i.agegrp i.child  c.c_edumax##ib3.yupar,  fe vce(cluster pid)
	margins i.yupar, post
	est store lsatswomen
restore

preserve
keep if sing==0 &  man==0
xtreg  lsat ib3.yupar i.agegrp i.child  c.c_edumax##ib3.yupar,  fe vce(cluster pid)
	margins i.yupar, post
	est store lsatpwomen
restore


coefplot ///
	(lsatswomen, label("Initially single") offset(0)  msymbol(S) mcolor(sky) msize(small) 	///
		lcolor(sky)     lpattern(solid) lcolor(sky) 						///
		ciopts(recast(rcap) lcolor(sky) lwidth(thin)))      		 			/// ///
	(lsatpwomen, label("Immediately coupled") offset(0) msymbol(T) mcolor(ply3) msize(small)			///
		lcolor(ply3)      lpattern(dash) lcolor(ply3)  						///
		ciopts(recast(rcap) lcolor(ply3)   lwidth(thin)))					///
			, 	title ("Women", size(med) color(black))									///
			vertical recast(connected) 									   		///
			ytitle("Life satisfaction", size(small)) 	///
			xtitle("Years Before / After Separation", size(small)) 		   		///
			xscale(titlegap(2)) xlab (, labsize(small)) 				   		///
			legend(position(6) rows(1) size(small) rowgap(.5) bmargin(zero)) 	///
			graphregion(color(white) fcolor(white) icolor(white))           	///
			ylab (6(0.5)7.5, labsize(small) angle(0))	
graph save "Graph" "${posted}\fig1_women.gph"

// men
preserve
keep if  sing==1 & man==1
xtreg  lsat ib3.yupar i.agegrp i.child  c.c_edumax##ib3.yupar,  fe vce(cluster pid)
	margins i.yupar, post
	est store lsatsmen
restore

preserve
keep if sing==0 &  man==1
xtreg  lsat ib3.yupar i.agegrp i.child  c.c_edumax##ib3.yupar,  fe vce(cluster pid)
	margins i.yupar, post
	est store lsatpmen
restore


coefplot ///
	(lsatsmen, label("Initially single") offset(0)  msymbol(S) mcolor(sky) msize(small) 	///
		lcolor(sky)     lpattern(solid) lcolor(sky) 						///
		ciopts(recast(rcap) lcolor(sky) lwidth(thin)))      		 			/// ///
	(lsatpmen, label("Immediately coupled") offset(0) msymbol(T) mcolor(ply3) msize(small)			///
		lcolor(ply3)      lpattern(dash) lcolor(ply3)  						///
		ciopts(recast(rcap) lcolor(ply3)   lwidth(thin)))					///
			, 	title ("Men", size(med) color(black))									///
			vertical recast(connected) 									   		///
			ytitle("Life satisfaction", size(small)) 	///
			xtitle("Years Before / After Separation", size(small)) 		   		///
			xscale(titlegap(2)) xlab (, labsize(small)) 				   		///
			legend(position(6) rows(1) size(small) rowgap(.5) bmargin(zero)) 	///
			graphregion(color(white) fcolor(white) icolor(white))           	///
			ylab (6(0.5)7.5, labsize(small) angle(0))	
			
graph save "Graph" "${posted}\fig1_men.gph"

// Figure 1
graph combine "${posted}\fig1_women.gph" "${posted}\fig1_men"

*** TABLE 2

preserve
keep if  man==0
xtreg  lsat ib2.yupar##i.sing  i.agegrp i.child c.c_edumax##ib2.yupar,  fe vce(cluster pid)
	estimates store womenlsat
restore

preserve
keep if  man==0
xtreg  lsat ib2.yupar##c.yearssingb  i.agegrp i.child c.c_edumax##ib2.yupar,  fe vce(cluster pid)
	estimates store womenlsat2
restore

preserve
keep if  man==1
xtreg  lsat ib2.yupar##i.sing  i.agegrp i.child c.c_edumax##ib2.yupar,  fe vce(cluster pid)
	estimates store menlsat
restore

preserve
keep if  man==1
xtreg  lsat ib2.yupar##c.yearssingb i.agegrp i.child c.c_edumax##ib2.yupar,  fe vce(cluster pid)
	estimates store menlsat2
restore


esttab womenlsat womenlsat2 menlsat  menlsat2 ///
using "${posted}\lsat.rtf", 	///
b(3) se long constant replace 

*******************************************************************************
* Labor earnings
********************************************************************************

*** Fixed effects models life satisfaction
** Figure 2 
drop if  i11110<0
gen lni11110 = ln(i11110)			// make the log
drop if lni11110==.

// women
preserve
	keep if  man==0 & sing==1
	xtreg  lni11110 ib3.yupar i.agegrp i.child  c.c_edumax##ib3.yupar,  fe vce(cluster pid)
	margins i.yupar, post expression(exp(predict(xb))*exp((`e(rmse)'^2)/2))
	estimates store incswoman
restore

preserve
	keep if  man==0 & sing==0
	xtreg  lni11110 ib3.yupar i.agegrp i.child  c.c_edumax##ib3.yupar,  fe vce(cluster pid)
	margins i.yupar, post expression(exp(predict(xb))*exp((`e(rmse)'^2)/2))
	estimates store incpwoman
restore


coefplot ///
	(incswoman, label("Initially single") offset(0)  msymbol(S) mcolor(sky) msize(small) 	///
		lcolor(sky)     lpattern(solid) lcolor(sky) 						///
		ciopts(recast(rcap) lcolor(sky) lwidth(thin)))      		 			/// ///
	(incpwoman, label("Immediately coupled") offset(0) msymbol(T) mcolor(ply3) msize(small)			///
		lcolor(ply3)      lpattern(dash) lcolor(ply3)  						///
		ciopts(recast(rcap) lcolor(ply3)   lwidth(thin)))					///
			, 	title ("Women", size(med) color(black))									///
			vertical recast(connected) 									   		///
			ytitle("Labor earnings (logged)", size(small)) 	///
			xtitle("Years Before / After Separation", size(small)) 		   		///
			xscale(titlegap(2)) xlab (, labsize(small)) 				   		///
			legend(position(6) rows(1) size(small) rowgap(.5) bmargin(zero)) 	///
			graphregion(color(white) fcolor(white) icolor(white))           	///
			ylab (8.8(0.2)10.4, labsize(small) angle(0))	
graph save "Graph" "${posted}\fig2_women.gph"

// men
preserve
	keep if  man==1 & sing==1
	xtreg  lni11110 ib3.yupar i.agegrp i.child  c.c_edumax##ib3.yupar,  fe vce(cluster pid)
	margins i.yupar, post expression(exp(predict(xb))*exp((`e(rmse)'^2)/2))
	estimates store incsman
restore

preserve
	keep if  man==1 & sing==0
	xtreg  lni11110 ib3.yupar i.agegrp i.child  c.c_edumax##ib3.yupar,  fe vce(cluster pid)
	margins i.yupar, post expression(exp(predict(xb))*exp((`e(rmse)'^2)/2))
	estimates store incpman
restore


coefplot ///
	(incsman, label("Initially single") offset(0)  msymbol(S) mcolor(sky) msize(small) 	///
		lcolor(sky)     lpattern(solid) lcolor(sky) 						///
		ciopts(recast(rcap) lcolor(sky) lwidth(thin)))      		 			/// ///
	(incpman, label("Immediately coupled") offset(0) msymbol(T) mcolor(ply3) msize(small)			///
		lcolor(ply3)      lpattern(dash) lcolor(ply3)  						///
		ciopts(recast(rcap) lcolor(ply3)   lwidth(thin)))					///
			, 	title ("Men", size(med) color(black))									///
			vertical recast(connected) 									   		///
			ytitle("Labor earnings (logged)", size(small)) 	///
			xtitle("Years Before / After Separation", size(small)) 		   		///
			xscale(titlegap(2)) xlab (, labsize(small)) 				   		///
			legend(position(6) rows(1) size(small) rowgap(.5) bmargin(zero)) 	///
			graphregion(color(white) fcolor(white) icolor(white))           	///
			ylab (8.8(0.2)10.4, labsize(small) angle(0))	
graph save "Graph" "${posted}\fig2_men.gph"


// Figure 2
graph combine "${posted}\fig2_women.gph" "${posted}\fig2_men"


*** TABLE 3

preserve
keep if  man==0
xtreg  lni11110 ib2.yupar##i.sing  i.agegrp i.child c.c_edumax##ib2.yupar,  fe vce(cluster pid)
	estimates store womeninc
restore

preserve
keep if  man==0
xtreg  lni11110 ib2.yupar##c.yearssingb  i.agegrp i.child c.c_edumax##ib2.yupar,  fe vce(cluster pid)
	estimates store womeninc2
restore

preserve
keep if  man==1
xtreg  lni11110 ib2.yupar##i.sing  i.agegrp i.child c.c_edumax##ib2.yupar,  fe vce(cluster pid)
	estimates store meninc
restore

preserve
keep if  man==1
xtreg  lni11110 ib2.yupar##c.yearssingb  i.agegrp i.child c.c_edumax##ib2.yupar,  fe vce(cluster pid)
	estimates store meninc2
restore


esttab womeninc womeninc2 meninc  meninc2 ///
using "${posted}\inc.rtf", 	///
b(3) se long constant replace 


********************************************************************************
*** Robustness checks 
********************************************************************************
use "${posted}\data3.dta", clear

*** without controlling for education (Figure O1-O2)
// Figure O1
drop if  lsat<0 					
drop if yupar<2


// women
preserve
keep if  sing==1 & man==0 
xtreg  lsat ib3.yupar i.agegrp i.child  ,  fe vce(cluster pid)
	margins i.yupar, post
	est store lsatswomen
restore

preserve
keep if sing==0 &  man==0
xtreg  lsat ib3.yupar i.agegrp i.child ,  fe vce(cluster pid)
	margins i.yupar, post
	est store lsatpwomen
restore


coefplot ///
	(lsatswomen, label("Initially single") offset(0)  msymbol(S) mcolor(sky) msize(small) 	///
		lcolor(sky)     lpattern(solid) lcolor(sky) 						///
		ciopts(recast(rcap) lcolor(sky) lwidth(thin)))      		 			/// ///
	(lsatpwomen, label("Immediately coupled") offset(0) msymbol(T) mcolor(ply3) msize(small)			///
		lcolor(ply3)      lpattern(dash) lcolor(ply3)  						///
		ciopts(recast(rcap) lcolor(ply3)   lwidth(thin)))					///
			, 	title ("Women, not controlled for education", size(med) color(black))									///
			vertical recast(connected) 									   		///
			ytitle("Life satisfaction", size(small)) 	///
			xtitle("Years Before / After Separation", size(small)) 		   		///
			xscale(titlegap(2)) xlab (, labsize(small)) 				   		///
			legend(position(6) rows(1) size(small) rowgap(.5) bmargin(zero)) 	///
			graphregion(color(white) fcolor(white) icolor(white))           	///
			ylab (6(0.5)7.5, labsize(small) angle(0))	
graph save "Graph" "${posted}\figo1_women.gph"

// men
preserve
keep if  sing==1 & man==1
xtreg  lsat ib3.yupar i.agegrp i.child  ,  fe vce(cluster pid)
	margins i.yupar, post
	est store lsatsmen
restore

preserve
keep if sing==0 &  man==1
xtreg  lsat ib3.yupar i.agegrp i.child  ,  fe vce(cluster pid)
	margins i.yupar, post
	est store lsatpmen
restore


coefplot ///
	(lsatsmen, label("Initially single") offset(0)  msymbol(S) mcolor(sky) msize(small) 	///
		lcolor(sky)     lpattern(solid) lcolor(sky) 						///
		ciopts(recast(rcap) lcolor(sky) lwidth(thin)))      		 			/// ///
	(lsatpmen, label("Immediately coupled") offset(0) msymbol(T) mcolor(ply3) msize(small)			///
		lcolor(ply3)      lpattern(dash) lcolor(ply3)  						///
		ciopts(recast(rcap) lcolor(ply3)   lwidth(thin)))					///
			, 	title ("Men, not controlled for education", size(med) color(black))									///
			vertical recast(connected) 									   		///
			ytitle("Life satisfaction", size(small)) 	///
			xtitle("Years Before / After Separation", size(small)) 		   		///
			xscale(titlegap(2)) xlab (, labsize(small)) 				   		///
			legend(position(6) rows(1) size(small) rowgap(.5) bmargin(zero)) 	///
			graphregion(color(white) fcolor(white) icolor(white))           	///
			ylab (6(0.5)7.5, labsize(small) angle(0))	
			
graph save "Graph" "${posted}\figo1_men.gph"

// Figure O1
graph combine "${posted}\figo1_women.gph" "${posted}\figo1_men"

***
// Figure O2
drop if  i11110<0
gen lni11110 = ln(i11110)			
drop if lni11110==.

preserve
	keep if  man==0 & sing==1
	xtreg  lni11110 ib3.yupar i.agegrp i.child,  fe vce(cluster pid)
	margins i.yupar, post // expression(exp(predict(xb))*exp((`e(rmse)'^2)/2))
	estimates store incswoman
restore

preserve
	keep if  man==0 & sing==0
	xtreg  lni11110 ib3.yupar i.agegrp i.child,  fe vce(cluster pid)
	margins i.yupar, post // expression(exp(predict(xb))*exp((`e(rmse)'^2)/2))
	estimates store incpwoman
restore


coefplot ///
	(incswoman, label("Initially single") offset(0)  msymbol(S) mcolor(sky) msize(small) 	///
		lcolor(sky)     lpattern(solid) lcolor(sky) 						///
		ciopts(recast(rcap) lcolor(sky) lwidth(thin)))      		 			/// ///
	(incpwoman, label("Immediately coupled") offset(0) msymbol(T) mcolor(ply3) msize(small)			///
		lcolor(ply3)      lpattern(dash) lcolor(ply3)  						///
		ciopts(recast(rcap) lcolor(ply3)   lwidth(thin)))					///
			, 	title ("Women, not controlled for education", size(med) color(black))									///
			vertical recast(connected) 									   		///
			ytitle("Labor earnings (logged)", size(small)) 	///
			xtitle("Years Before / After Separation", size(small)) 		   		///
			xscale(titlegap(2)) xlab (, labsize(small)) 				   		///
			legend(position(6) rows(1) size(small) rowgap(.5) bmargin(zero)) 	///
			graphregion(color(white) fcolor(white) icolor(white))           	///
			ylab (8.8(0.2)10.4, labsize(small) angle(0))	
graph save "Graph" "${posted}\figo2_women.gph", replace

preserve
	keep if  man==1 & sing==1
	xtreg  lni11110 ib3.yupar i.agegrp i.child ,  fe vce(cluster pid)
	margins i.yupar, post // expression(exp(predict(xb))*exp((`e(rmse)'^2)/2))
	estimates store incsman
restore

preserve
	keep if  man==1 & sing==0
	xtreg  lni11110 ib3.yupar i.agegrp i.child,  fe vce(cluster pid)
	margins i.yupar, post // expression(exp(predict(xb))*exp((`e(rmse)'^2)/2))
	estimates store incpman
restore


coefplot ///
	(incsman, label("Initially single") offset(0)  msymbol(S) mcolor(sky) msize(small) 	///
		lcolor(sky)     lpattern(solid) lcolor(sky) 						///
		ciopts(recast(rcap) lcolor(sky) lwidth(thin)))      		 			/// ///
	(incpman, label("Immediately coupled") offset(0) msymbol(T) mcolor(ply3) msize(small)			///
		lcolor(ply3)      lpattern(dash) lcolor(ply3)  						///
		ciopts(recast(rcap) lcolor(ply3)   lwidth(thin)))					///
			, 	title ("Men, not controlled for education", size(med) color(black))									///
			vertical recast(connected) 									   		///
			ytitle("Labor earnings (logged)", size(small)) 	///
			xtitle("Years Before / After Separation", size(small)) 		   		///
			xscale(titlegap(2)) xlab (, labsize(small)) 				   		///
			legend(position(6) rows(1) size(small) rowgap(.5) bmargin(zero)) 	///
			graphregion(color(white) fcolor(white) icolor(white))           	///
			ylab (8.8(0.2)10.4, labsize(small) angle(0))	
graph save "Graph" "${posted}\figo2_men.gph", replace

graph combine "${posted}\figo2_women.gph" "${posted}\figo2_men"

*******************************************************************************
*** Survival analyses repartnering

use "${posted}\data2.dta", clear

* Keep only people who experience separation 
keep if max_unpart ==1 
distinct pid
gen yearspartnered = ageunpart - agepart
keep if age>=agepart						// keep only from partnering onwards

// make variable for years since/from unpartnered
recode yunpar 	(-3 = 1 "-3") (-2 = 2 "-2") (-1 = 3  "-1") ///
				(0 = 4 "0") (1 = 5 "1") (2 = 6 "2") (3 = 7 "3")  (else=.) , gen(yupar)
drop if yupar==.		// keep only from -3 to +3 window
sort pid syear
bys pid: egen min_yunpar = min(yupar)
bys pid: egen max_yunpar = max(yupar)


// keep only if not repartnered
drop if yupar<4

// keep to age 45
keep if age<45
distinct pid

// keep only if observed before and after
keep if min_yunpar<4 & max_yunpar>=4


// year repartnered
gen yearrepart = syear if partner==1
bys pid: egen min_yearrepart = min(yearrepart)
drop if syear> min_yearrepart

// survival curves
replace yupar = yupar-4

stset yupar, id(pid) failure(partner)

// women
preserve
keep if man==0
sts graph, by(sing)	title ("Women", size(med) color(black))						///
			xtitle("Years since Separation", size(small))						/// 	
	   		legend(position(6) rows(1) size(small) rowgap(.5) bmargin(zero)) 	
graph save "Graph" "${posted}\figo3_women.gph", replace
			
restore 

// men
preserve
keep if man==1
sts graph, by(sing)	title ("Men", size(med) color(black))						///
			xtitle("Years since Separation", size(small))						/// 	
	   		legend(position(6) rows(1) size(small) rowgap(.5) bmargin(zero)) 	
graph save "Graph" "${posted}\figo3_men.gph", replace
			
restore 

graph combine "${posted}\figo3_women.gph" "${posted}\figo3_men"


*******************************************************************************
// main analyses without missing, robstness check with 
drop if  lsat<0 | edumax<0					
drop if yupar<2
center edumax

*** Additional control variables included
// years partnered
preserve
keep if  man==0 
xtreg  lsat ib3.yupar##i.sing i.agegrp i.child c.c_edumax##ib3.yupar c.yearspartnered##ib3.yupar,  fe vce(cluster pid)
restore

preserve
keep if man==1
xtreg  lsat ib3.yupar##i.sing i.agegrp i.child  c.c_edumax##ib3.yupar c.yearspartnered##ib3.yupar, fe vce(cluster pid)
restore

// age at leaving home
preserve
keep if  man==0 
xtreg  lsat ib3.yupar##i.sing i.agegrp i.child c.c_edumax##ib3.yupar c.agemov##ib3.yupar,  fe vce(cluster pid)
restore

preserve
keep if man==1
xtreg  lsat ib3.yupar##i.sing i.agegrp i.child  c.c_edumax##ib3.yupar c.agemov##ib3.yupar, fe vce(cluster pid)
restore

// survey year
preserve
keep if  man==0 
xtreg  lsat ib3.yupar##i.sing i.agegrp i.child c.c_edumax##ib3.yupar c.syear##ib3.yupar,  fe vce(cluster pid)
restore

preserve
keep if man==1
xtreg  lsat ib3.yupar##i.sing i.agegrp i.child  c.c_edumax##ib3.yupar c.syear##ib3.yupar, fe vce(cluster pid)
restore

// married
recode pgfamstd (1 2 5 6 = 1) (else=0), gen(married)
replace married=0 if yupar>3
bys pid: egen ever_mar = max(married)

preserve
keep if  man==0 
xtreg  lsat ib3.yupar##i.sing i.agegrp i.child c.c_edumax##ib3.yupar i.ever_mar##ib3.yupar,  fe vce(cluster pid)
restore

preserve
keep if man==1
xtreg  lsat ib3.yupar##i.sing i.agegrp i.child  c.c_edumax##ib3.yupar i.ever_mar##ib3.yupar, fe vce(cluster pid)
restore

*******************************************************************************
*** Satisfaction with family life 
use "${posted}\data3.dta", clear

drop if  lsat<0 | edumax<0					
drop if yupar<2
center edumax

recode plh0180 (-8 -1 = . ), gen(famsat)
replace famsat=. if yupar>3
bys pid: egen mean_famsat = mean(famsat)
drop if mean_famsat==.
distinct pid

// women
preserve
keep if  sing==1 & man==0 
xtreg  lsat ib3.yupar i.agegrp i.child c.c_edumax##ib3.yupar c.mean_famsat ,  fe vce(cluster pid)
	margins i.yupar, post
	est store lsatswomenb
restore

preserve
keep if sing==0 &  man==0
xtreg  lsat ib3.yupar i.agegrp i.child c.c_edumax##ib3.yupar c.mean_famsat ,  fe vce(cluster pid)
	margins i.yupar, post
	est store lsatpwomenb
restore


coefplot ///
	(lsatswomenb, label("Initially single") offset(0)  msymbol(S) mcolor(sky) msize(small) 	///
		lcolor(sky)     lpattern(solid) lcolor(sky) 						///
		ciopts(recast(rcap) lcolor(sky) lwidth(thin)))      		 			/// ///
	(lsatpwomenb, label("Immediately coupled") offset(0) msymbol(T) mcolor(ply3) msize(small)			///
		lcolor(ply3)      lpattern(dash) lcolor(ply3)  						///
		ciopts(recast(rcap) lcolor(ply3)   lwidth(thin)))					///
			, 	title ("Women, controlled for sat. family life", size(med) color(black))									///
			vertical recast(connected) 									   		///
			ytitle("Life satisfaction", size(small)) 	///
			xtitle("Years Before / After Separation", size(small)) 		   		///
			xscale(titlegap(2)) xlab (, labsize(small)) 				   		///
			legend(position(6) rows(1) size(small) rowgap(.5) bmargin(zero)) 	///
			graphregion(color(white) fcolor(white) icolor(white))           	///
			ylab (6(0.5)7.5, labsize(small) angle(0))	
graph save "Graph" "${posted}\figo4_women.gph"

// men
preserve
keep if  sing==1 & man==1
xtreg  lsat ib3.yupar i.agegrp i.child c.c_edumax##ib3.yupar c.mean_famsat ,  fe vce(cluster pid)
	margins i.yupar, post
	est store lsatsmenb
restore

preserve
keep if sing==0 &  man==1
xtreg  lsat ib3.yupar i.agegrp i.child c.c_edumax##ib3.yupar c.mean_famsat ,  fe vce(cluster pid)
	margins i.yupar, post
	est store lsatpmenb
restore


coefplot ///
	(lsatsmenb, label("Initially single") offset(0)  msymbol(S) mcolor(sky) msize(small) 	///
		lcolor(sky)     lpattern(solid) lcolor(sky) 						///
		ciopts(recast(rcap) lcolor(sky) lwidth(thin)))      		 			/// ///
	(lsatpmenb, label("Immediately coupled") offset(0) msymbol(T) mcolor(ply3) msize(small)			///
		lcolor(ply3)      lpattern(dash) lcolor(ply3)  						///
		ciopts(recast(rcap) lcolor(ply3)   lwidth(thin)))					///
			, 	title ("Men, controlled for sat. family life", size(med) color(black))									///
			vertical recast(connected) 									   		///
			ytitle("Life satisfaction", size(small)) 	///
			xtitle("Years Before / After Separation", size(small)) 		   		///
			xscale(titlegap(2)) xlab (, labsize(small)) 				   		///
			legend(position(6) rows(1) size(small) rowgap(.5) bmargin(zero)) 	///
			graphregion(color(white) fcolor(white) icolor(white))           	///
			ylab (6(0.5)7.5, labsize(small) angle(0))	
graph save "Graph" "${posted}\figo4_men.gph"
			
// Figure O4
graph combine "${posted}\figo4_women.gph" "${posted}\figo4_men"

***
// Figure O5
drop if  i11110<0
gen lni11110 = ln(i11110)			
drop if lni11110==.

preserve
	keep if  man==0 & sing==1
	xtreg  lni11110 ib3.yupar i.agegrp i.child c.c_edumax##ib3.yupar c.mean_famsat,  fe vce(cluster pid)
	margins i.yupar, post // expression(exp(predict(xb))*exp((`e(rmse)'^2)/2))
	estimates store incswoman
restore

preserve
	keep if  man==0 & sing==0
	xtreg  lni11110 ib3.yupar i.agegrp i.child c.c_edumax##ib3.yupar c.mean_famsat,  fe vce(cluster pid)
	margins i.yupar, post // expression(exp(predict(xb))*exp((`e(rmse)'^2)/2))
	estimates store incpwoman
restore


coefplot ///
	(incswoman, label("Initially single") offset(0)  msymbol(S) mcolor(sky) msize(small) 	///
		lcolor(sky)     lpattern(solid) lcolor(sky) 						///
		ciopts(recast(rcap) lcolor(sky) lwidth(thin)))      		 			/// ///
	(incpwoman, label("Immediately coupled") offset(0) msymbol(T) mcolor(ply3) msize(small)			///
		lcolor(ply3)      lpattern(dash) lcolor(ply3)  						///
		ciopts(recast(rcap) lcolor(ply3)   lwidth(thin)))					///
			, 	title ("Women, controlled for sat. family life", size(med) color(black))									///
			vertical recast(connected) 									   		///
			ytitle("Labor earnings (logged)", size(small)) 	///
			xtitle("Years Before / After Separation", size(small)) 		   		///
			xscale(titlegap(2)) xlab (, labsize(small)) 				   		///
			legend(position(6) rows(1) size(small) rowgap(.5) bmargin(zero)) 	///
			graphregion(color(white) fcolor(white) icolor(white))           	///
			ylab (8.8(0.2)10.4, labsize(small) angle(0))	
graph save "Graph" "${posted}\figo5_women.gph", replace

preserve
	keep if  man==1 & sing==1
	xtreg  lni11110 ib3.yupar i.agegrp i.child c.c_edumax##ib3.yupar c.mean_famsat,  fe vce(cluster pid)
	margins i.yupar, post // expression(exp(predict(xb))*exp((`e(rmse)'^2)/2))
	estimates store incsman
restore

preserve
	keep if  man==1 & sing==0
	xtreg  lni11110 ib3.yupar i.agegrp i.child c.c_edumax##ib3.yupar c.mean_famsat,  fe vce(cluster pid)
	margins i.yupar, post // expression(exp(predict(xb))*exp((`e(rmse)'^2)/2))
	estimates store incpman
restore


coefplot ///
	(incsman, label("Initially single") offset(0)  msymbol(S) mcolor(sky) msize(small) 	///
		lcolor(sky)     lpattern(solid) lcolor(sky) 						///
		ciopts(recast(rcap) lcolor(sky) lwidth(thin)))      		 			/// ///
	(incpman, label("Immediately coupled") offset(0) msymbol(T) mcolor(ply3) msize(small)			///
		lcolor(ply3)      lpattern(dash) lcolor(ply3)  						///
		ciopts(recast(rcap) lcolor(ply3)   lwidth(thin)))					///
			, 	title ("Men, controlled for sat. family life", size(med) color(black))									///
			vertical recast(connected) 									   		///
			ytitle("Labor earnings (logged)", size(small)) 	///
			xtitle("Years Before / After Separation", size(small)) 		   		///
			xscale(titlegap(2)) xlab (, labsize(small)) 				   		///
			legend(position(6) rows(1) size(small) rowgap(.5) bmargin(zero)) 	///
			graphregion(color(white) fcolor(white) icolor(white))           	///
			ylab (8.8(0.2)10.4, labsize(small) angle(0))	
graph save "Graph" "${posted}\figo5_men.gph", replace

graph combine "${posted}\figo5_women.gph" "${posted}\figo5_men"


********************************************************************************
*** HYBRID
********************************************************************************
use "${posted}\data3.dta", clear

drop if  lsat<0 | edumax<0					
drop if yupar<2
center edumax

recode yupar (2 =1) (else = 0), gen (twoybef)
recode yupar (3 =1) (else = 0), gen (oneybef)
recode yupar (4 =1) (else = 0), gen (ydiv)
recode yupar (5 =1) (else = 0), gen (oneyaf)
recode yupar (6 =1) (else = 0), gen (twoyaf)
recode yupar (7 =1) (else = 0), gen (threeyaf)

gen yearssing2 = yearssing*yearssing

foreach var of varlist twoybef oneybef ydiv oneyaf twoyaf threeyaf {
	bys pid: egen m`var' = mean(`var')
	gen d`var' = `var' - m`var'
	gen `var'sing = `var'*sing
	bys pid: egen m`var'sing = mean(`var'sing)
	gen d`var'sing = `var'sing - m`var'sing
	gen c_edumax`var'=c_edumax*`var'
	bys pid: egen mc_max_edu`var' = mean(c_edumax`var')
	gen dc_max_edu`var' = c_edumax`var' - mc_max_edu`var' 
	gen yssing`var' = yearssing*`var'
	bys pid: egen myssing`var' = mean(yssing`var')
	gen dyssing`var' = yssing`var' - myssing`var'
	gen yssing2`var' = yearssing2*`var'
	bys pid: egen myssing2`var' = mean(yssing2`var')
	gen dyssing2`var' = yssing2`var' - myssing2`var'
}


** Test if this model is prefered over random model
mixed lsat dtwoybef dydiv doneyaf dtwoyaf dthreeyaf mtwoybef mydiv moneyaf mtwoyaf mthreeyaf || pid:
test dtwoybef=mtwoybef
test dydiv=mydiv
test doneyaf=moneyaf
test dtwoyaf=mtwoyaf
test dthreeyaf=mthreeyaf

test (dtwoybef=mtwoybef) (dydiv=mydiv) (doneyaf=moneyaf) (dtwoyaf=mtwoyaf) (dthreeyaf=mthreeyaf)

gen lni11110 = ln(i11110)

preserve
drop if i11110==.

mixed lni11110 dtwoybef dydiv doneyaf dtwoyaf dthreeyaf mtwoybef mydiv moneyaf mtwoyaf mthreeyaf || pid:
test dtwoybef=mtwoybef
test dydiv=mydiv
test doneyaf=moneyaf
test dtwoyaf=mtwoyaf
test dthreeyaf=mthreeyaf

test (dtwoybef=mtwoybef) (dydiv=mydiv) (doneyaf=moneyaf) (dtwoyaf=mtwoyaf) (dthreeyaf=mthreeyaf)
restore


*** Model 1
preserve 

keep if man==1

mixed lsat doneybef* dydiv* doneyaf* dtwoyaf* dthreeyaf* moneybef* mydiv* moneyaf* mtwoyaf* mthreeyaf*	///
i.sing  i.child c.c_edumax mc_max_eduoneybef dc_max_eduoneybef  						/// 
dc_max_eduydiv mc_max_eduydiv dc_max_eduoneyaf mc_max_eduoneyaf 						///
mc_max_edutwoyaf dc_max_edutwoyaf mc_max_eduthreeyaf dc_max_eduthreeyaf 				///
i.agegrp || pid: 
estimates store menlsathybrid

restore

preserve 

keep if man==0

mixed lsat doneybef* dydiv* doneyaf* dtwoyaf* dthreeyaf* moneybef* mydiv* moneyaf* mtwoyaf* mthreeyaf*	///
i.sing  i.child c.c_edumax mc_max_eduoneybef dc_max_eduoneybef  						/// 
dc_max_eduydiv mc_max_eduydiv dc_max_eduoneyaf mc_max_eduoneyaf 						///
mc_max_edutwoyaf dc_max_edutwoyaf mc_max_eduthreeyaf dc_max_eduthreeyaf 				///
i.agegrp || pid: 
estimates store womenlsathybrid

restore

/// Table O2 Model 1
esttab  menlsathybrid  womenlsathybrid    ///
using "${posted}\lsat.rtf", 	///
b(3) se  constant replace 


*** Model 2 
drop if  i11110<0

preserve 

keep if man==1

mixed lni11110 doneybef* dydiv* doneyaf* dtwoyaf* dthreeyaf* moneybef* mydiv* moneyaf* mtwoyaf* mthreeyaf*	///
i.sing  i.child c.c_edumax mc_max_eduoneybef dc_max_eduoneybef  						/// 
dc_max_eduydiv mc_max_eduydiv dc_max_eduoneyaf mc_max_eduoneyaf 						///
mc_max_edutwoyaf dc_max_edutwoyaf mc_max_eduthreeyaf dc_max_eduthreeyaf 				///
i.agegrp || pid: 
estimates store meninchybrid

restore

preserve 

keep if man==0

mixed lni11110 doneybef* dydiv* doneyaf* dtwoyaf* dthreeyaf* moneybef* mydiv* moneyaf* mtwoyaf* mthreeyaf*	///
i.sing  i.child c.c_edumax mc_max_eduoneybef dc_max_eduoneybef  						/// 
dc_max_eduydiv mc_max_eduydiv dc_max_eduoneyaf mc_max_eduoneyaf 						///
mc_max_edutwoyaf dc_max_edutwoyaf mc_max_eduthreeyaf dc_max_eduthreeyaf 				///
i.agegrp || pid: 
estimates store womeninchybrid

restore

*** Table O2 Model 2
esttab  meninchybrid  womeninchybrid    ///
using "${posted}\inc.rtf", 	///
b(3) se  constant replace 

